@@ -617,7 +617,7 @@ int MM_Evt(SDL_Event *e)
                 return MM_UseE(MM_DEC);
         case SDL_KEYUP:
             switch (e->key.keysym.sym) {
-                case SDLK_KP_ENTER:
+                case SDLK_RETURN:
                     return MM_UseE(MM_NONE);
                 case SDLK_UP:
                     return MM_PrvE();
