@@ -83,7 +83,7 @@ void load_res( Pairs *pairs )
     } */
     
     /* font */
-    pairs->font = load_fixed_font( "stan_font.bmp" , 32, 96, 8);
+    pairs->font = load_fixed_font( "f_standard.bmp" , 32, 96, 10);
 
     /* sounds */
 #ifdef SOUND
@@ -151,6 +151,8 @@ int open_game( Pairs *pairs, int width, int height )
 {
     int i, dummy, pos1, pos2;
     int map_size = width * height;
+    int pair_num = map_size / 2;
+    int pair_ids[ICON_NUMBER]; /* all ids, first will be selected */
     int leave = 0;
     SDL_Event event;
     int reveal_time = 0;
@@ -173,16 +175,25 @@ int open_game( Pairs *pairs, int width, int height )
     /* pairs to go */
     pairs->pairs_left = map_size / 2;
 
+	/* randomly choose pairnum pairs */
+	for (i = 0; i < ICON_NUMBER; i++)
+		pair_ids[i] = i;
+	for (i = 0; i < ICON_NUMBER*20; i++) {
+		pos1 = rand() % ICON_NUMBER;
+		pos2 = rand() % ICON_NUMBER;
+		dummy = pair_ids[pos1];
+		pair_ids[pos1] = pair_ids[pos2];
+		pair_ids[pos2] = dummy;
+	}
+
     /* recreate map */
     pairs->map = calloc( map_size, sizeof( int ) );
     /* add sorted pairs */
     i = 0;
-    while ( i < map_size / 2 ) {
-
-        pairs->map[i] = i;
-        pairs->map[i + map_size / 2] = i;
+    while ( i < pair_num ) {
+        pairs->map[i] = pair_ids[i];
+        pairs->map[i + map_size / 2] = pair_ids[i];
         i++;
-
     }
     /* unsort these pairs */
     for ( i = 0; i < map_size * 20; i++ ) {
@@ -255,7 +266,7 @@ int open_game( Pairs *pairs, int width, int height )
 
                 }
 
-            SDL_Delay( 5 );
+            SDL_Delay( 1 );
 
         }
 
@@ -271,7 +282,31 @@ int open_game( Pairs *pairs, int width, int height )
 void close_game( Pairs *pairs )
 {
     if ( cfg.fullscreen )
-        set_video_mode( 800, 480, 16, SDL_FULLSCREEN );
+        set_video_mode( 640, 480, 16, SDL_SWSURFACE );
+}
+
+/* init card removal animation */
+void init_card_animation(Pairs *pairs, int mx1, int my1, int mx2, int my2)
+{
+	int sx1 = pairs->x_offset + mx1 * ( BUTTON_WIDTH + BORDER );
+	int sy1 = pairs->y_offset + my1 * ( BUTTON_HEIGHT + BORDER );
+	int sx2 = pairs->x_offset + mx2 * ( BUTTON_WIDTH + BORDER );
+	int sy2 = pairs->y_offset + my2 * ( BUTTON_HEIGHT + BORDER );
+	int dx = (sx1 + sx2)/2, dy = (sy1 + sy2)/2;
+	int sa = 0, da = 192;
+	SDL_Surface *img = 0;
+	
+	img = create_surf(BUTTON_WIDTH, BUTTON_HEIGHT, SDL_SWSURFACE);
+	DEST(img,0,0,img->w,img->h);
+	SOURCE(sdl.screen,sx1,sy1)
+	blit_surf();
+	sa_init(&pairs->anim1,img,sx1,sy1,sa,dx,dy,da,300);
+	
+	img = create_surf(BUTTON_WIDTH, BUTTON_HEIGHT, SDL_SWSURFACE);
+	DEST(img,0,0,img->w,img->h);
+	SOURCE(sdl.screen,sx2,sy2)
+	blit_surf();
+	sa_init(&pairs->anim2,img,sx2,sy2,sa,dx,dy,da,300);
 }
 
 /* run game */
@@ -282,7 +317,6 @@ void run_game( Pairs *pairs )
     int x, y;
     int ms;
     char str[128];
-    int removed = 0;
     int restart = 0;
 
     reset_timer();
@@ -294,12 +328,14 @@ void run_game( Pairs *pairs )
             switch ( event.type ) {
 
                 case SDL_KEYUP:
-                    if ( event.key.keysym.sym == SDLK_BACKSPACE ) leave = 1;
+                    if ( event.key.keysym.sym == SDLK_ESCAPE ) leave = 1;
                     if ( event.key.keysym.sym == SDLK_r ) restart = 1;
                     break;
 
                 case SDL_MOUSEBUTTONUP:
-                    if ( event.button.button == LEFT_BUTTON && pairs->status != BOTH_SEL )
+                    if ( event.button.button == LEFT_BUTTON && 
+										pairs->status != BOTH_SEL && 
+										pairs->status != REMOVE_CARDS )
                         if ( get_map_pos( pairs, event.button.x, event.button.y, &x, &y ) ) {
 
                             /* same tile? */
@@ -347,11 +383,32 @@ void run_game( Pairs *pairs )
 
         }
 
-        /* get millisceonds */
+        /* get milliseconds */
         ms = get_time();
 
         /* add time */
-        pairs->time += ms;
+        if (pairs->status != REMOVE_CARDS)
+			pairs->time += ms;
+		else {
+			if (sa_update(&pairs->anim1,ms) || sa_update(&pairs->anim2,ms)) {
+				/* both reach destination at the same time */
+				pairs->pairs_left--;
+                if ( pairs->pairs_left <= 0 )
+                    pairs->status = DONE;
+                else
+					pairs->status = NO_SEL;
+
+				sa_finalize(&pairs->anim1);
+				sa_finalize(&pairs->anim2);
+				sa_draw_background();
+				sdl.rect_count = RECT_LIMIT; /* XXX fake full update */
+			} else {
+				sa_draw_background();
+				sa_draw(&pairs->anim1);
+				sa_draw(&pairs->anim2);
+				sdl.rect_count = RECT_LIMIT; /* XXX fake full update */
+			}
+		}
 
         /* check if buttons must be closed */
         if ( pairs->status == BOTH_SEL ) {
@@ -369,30 +426,28 @@ void run_game( Pairs *pairs )
         /* close buttons? */
         if ( pairs->status == CLOSE_SEL ) {
 
-            removed = 0;
-
-            /* remove buttons? */
-            if ( get_map_cont( pairs, pairs->first_sel.x, pairs->first_sel.y ) ==
-                 get_map_cont( pairs, pairs->sec_sel.x, pairs->sec_sel.y ) ) {
-
-                removed = 1;
+            /* remove cards? */
+            if (get_map_cont(pairs, pairs->first_sel.x, pairs->first_sel.y) ==
+                get_map_cont(pairs, pairs->sec_sel.x, pairs->sec_sel.y )) {
 
+				pairs->status = REMOVE_CARDS;
+                init_card_animation(pairs, 
+								pairs->first_sel.x, pairs->first_sel.y,
+								pairs->sec_sel.x, pairs->sec_sel.y);
+                
                 set_map_cont( pairs, pairs->first_sel.x, pairs->first_sel.y, -1 );
                 set_map_cont( pairs, pairs->sec_sel.x, pairs->sec_sel.y, -1 );
-                pairs->pairs_left--;
-
-                if ( pairs->pairs_left <= 0 )
-                    pairs->status = DONE;
-
             }
 
             draw_button( pairs, pairs->first_sel.x, pairs->first_sel.y, CLOSED );
             draw_button( pairs, pairs->sec_sel.x, pairs->sec_sel.y, CLOSED );
-            if ( pairs->status != DONE )
-                pairs->status = NO_SEL;
+            if (pairs->status != REMOVE_CARDS)
+				pairs->status = NO_SEL;
+			else
+				sa_get_background();
 
 #ifdef SOUND
-            if ( removed )
+            if ( pairs->status == REMOVE_CARDS )
                 SSrv_Ply(pairs->remove_sound, 0);
             else
                 SSrv_Ply(pairs->fail_sound, 0);
@@ -401,7 +456,7 @@ void run_game( Pairs *pairs )
             pairs->tries++;
 
         }
-
+        
         draw_info( pairs );
 
         refresh_rects();
@@ -424,14 +479,12 @@ void run_game( Pairs *pairs )
                 pairs->font->align = ALIGN_X_CENTER | ALIGN_Y_TOP;
                 y = ( sdl.screen->h >> 1 ) - 50;
 
-                sprintf( str, _("Congratulations! You have resolved this puzzle!") );
+                sprintf( str, _("Congratulations!") );
                 write_text( pairs->font, sdl.screen, sdl.screen->w >> 1, y, str, OPAQUE );
-                sprintf( str, _("It now will restart with the same settings.") );
+                sprintf( str, _("Press ESC to exit or") );
                 write_text( pairs->font, sdl.screen, sdl.screen->w >> 1, y + 20, str, OPAQUE );
-                sprintf( str, _("If you want to change these press <Escape> after restart.") );
+                sprintf( str, _("any other key to restart.") );
                 write_text( pairs->font, sdl.screen, sdl.screen->w >> 1, y + 40, str, OPAQUE );
-                sprintf( str, _("(Press any key to continue...)") );
-                write_text( pairs->font, sdl.screen, sdl.screen->w >> 1, y + 60, str, OPAQUE );
 
                 refresh_screen( 0, 0, 0, 0 );
 
@@ -446,7 +499,7 @@ void run_game( Pairs *pairs )
 
             }
 
-        SDL_Delay( 5 );
+        SDL_Delay( 1 );
     }
 
     if ( cfg.dim )
@@ -499,13 +552,13 @@ void draw_button( Pairs *pairs, int map_x, int map_y, int type )
 }
 
 /* get map contents at position */
-inline int get_map_cont( Pairs *pairs, int map_x, int map_y )
+int get_map_cont( Pairs *pairs, int map_x, int map_y )
 {
     return ( pairs->map[map_y * pairs->width + map_x] );
 }
 
 /* set map contents at position */
-inline void set_map_cont( Pairs *pairs, int map_x, int map_y, int cont )
+void set_map_cont( Pairs *pairs, int map_x, int map_y, int cont )
 {
     pairs->map[map_y * pairs->width + map_x] = cont;
 }
