@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/timeb.h>
+#include <math.h>
 #include "sdl.h"
 
 extern int  term_game;
@@ -31,7 +32,7 @@ int cur_time, last_time;
 // sdl surface //
 
 /* return full path of bitmap */
-inline void get_full_bmp_path( char *full_path, char *file_name )
+void get_full_bmp_path( char *full_path, char *file_name )
 {
     sprintf(full_path,  "%sgfx/%s", SRC_DIR, file_name );
 }
@@ -110,7 +111,7 @@ int disp_format(SDL_Surface *sur)
 /*
     lock surface
 */
-inline void lock_surf(SDL_Surface *sur)
+void lock_surf(SDL_Surface *sur)
 {
     if (SDL_MUSTLOCK(sur))
         SDL_LockSurface(sur);
@@ -119,7 +120,7 @@ inline void lock_surf(SDL_Surface *sur)
 /*
     unlock surface
 */
-inline void unlock_surf(SDL_Surface *sur)
+void unlock_surf(SDL_Surface *sur)
 {
     if (SDL_MUSTLOCK(sur))
         SDL_UnlockSurface(sur);
@@ -354,7 +355,7 @@ int write_text(Font *fnt, SDL_Surface *dest, int x, int y, char *str, int alpha)
 /*
     lock font surface
 */
-inline void lock_font(Font *fnt)
+void lock_font(Font *fnt)
 {
     if (SDL_MUSTLOCK(fnt->pic))
         SDL_LockSurface(fnt->pic);
@@ -363,7 +364,7 @@ inline void lock_font(Font *fnt)
 /*
     unlock font surface
 */
-inline void unlock_font(Font *fnt)
+void unlock_font(Font *fnt)
 {
     if (SDL_MUSTLOCK(fnt->pic))
         SDL_UnlockSurface(fnt->pic);
@@ -440,8 +441,6 @@ int	set_video_mode(int w, int h, int d, int f)
         return 1;
     }
 
-    SDL_ShowCursor(0);
-
 #ifdef SDL_DEBUG				
     if (f & SDL_HWSURFACE && !(sdl.screen->flags & SDL_HWSURFACE))
        	fprintf(stderr, "unable to create screen in hardware memory...\n");
@@ -482,7 +481,7 @@ void hardware_cap()
 /*
     update rectangle (0,0,0,0)->fullscreen
 */
-inline void refresh_screen(int x, int y, int w, int h)
+void refresh_screen(int x, int y, int w, int h)
 {
     SDL_UpdateRect(sdl.screen, x, y, w, h);
 }
@@ -632,7 +631,7 @@ void wait_for_click()
 /*
     lock surface
 */
-inline void lock_screen()
+void lock_screen()
 {
     if (SDL_MUSTLOCK(sdl.screen))
         SDL_LockSurface(sdl.screen);
@@ -641,7 +640,7 @@ inline void lock_screen()
 /*
     unlock surface
 */
-inline void unlock_screen()
+void unlock_screen()
 {
     if (SDL_MUSTLOCK(sdl.screen))
         SDL_UnlockSurface(sdl.screen);
@@ -650,7 +649,7 @@ inline void unlock_screen()
 /*
     flip hardware screens (double buffer)
 */
-inline void flip_screen()
+void flip_screen()
 {
     SDL_Flip(sdl.screen);
 }
@@ -729,3 +728,77 @@ void reset_timer()
 {
     last_time = SDL_GetTicks();
 }
+
+
+/* Simple Animation */
+
+SDL_Surface *sa_background = 0; /* copy of screen contents */
+
+void sa_get_background()
+{
+	if (sa_background == 0)
+		sa_background = create_surf(sdl.screen->w, sdl.screen->h, SDL_SWSURFACE);
+	FULL_DEST(sa_background);
+    FULL_SOURCE(sdl.screen);
+    blit_surf();
+}
+void sa_free_background()
+{
+	if (sa_background)
+		SDL_FreeSurface(sa_background);
+	sa_background = 0;
+}
+void sa_draw_background()
+{
+	FULL_DEST(sdl.screen);
+    FULL_SOURCE(sa_background);
+    blit_surf();
+}
+
+void sa_init(SimpleAnimation *anim, SDL_Surface *img, 
+			int sx, int sy, int sa, int dx, int dy, int da, int time)
+{
+	double len, v;
+	
+	anim->image = img;
+	anim->px = sx;
+	anim->py = sy;
+	anim->pa = sa;
+	
+	/* compute speed vector */
+	anim->vx = dx - sx;
+	anim->vy = dy - sy;
+	len = sqrt(anim->vx * anim->vx + anim->vy * anim->vy);
+	v = len / time;	/* time is in milliseconds */
+	anim->vx = anim->vx / len * v;
+	anim->vy = anim->vy / len * v;
+	
+	/* compute alpha vector */
+	anim->va = (double)(da - sa) / time;
+	
+	anim->runtime = time;
+}
+void sa_finalize(SimpleAnimation *anim)
+{
+	SDL_FreeSurface(anim->image);
+	anim->image = 0;
+	anim->runtime = 0;
+}
+int sa_update(SimpleAnimation *anim, int ms)
+{
+	if (anim->runtime > 0) {
+		anim->px += anim->vx * ms;
+		anim->py += anim->vy * ms;
+		anim->pa += anim->va * ms;
+		anim->runtime -= ms;
+	}
+	return (anim->runtime <= 0);
+}
+void sa_draw(SimpleAnimation *anim)
+{
+	if (anim->image) {
+		DEST( sdl.screen, anim->px, anim->py, anim->image->w, anim->image->h );
+		SOURCE( anim->image, 0, 0 );
+		alpha_blit_surf(anim->pa);
+	}
+}
